@@ -1,6 +1,6 @@
 /* A menu that places itself in the middle of the canvas.
  *
- * Copyright (c) 2003 Ole Laursen.
+ * Copyright (c) 2003, 2004 Ole Laursen.
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -40,7 +40,7 @@ public:
   struct Action
   {
     Glib::ustring label;
-    SigC::Slot0<void> callback;
+    sigc::slot<void> callback;
   };
 
   typedef std::vector<Action> action_sequence;
