@@ -23,10 +23,10 @@
 
 #include "helpers.hpp"
 
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
 
 
-class Intro: public SigC::Object, noncopyable
+class Intro: public sigc::trackable, noncopyable
 {
 public:
   Intro();
